.. _kodi:

====
Kóði
====

Stillingar
==========

.. automodule:: korta.defaults
   :members:

Client
======

.. automodule:: korta.client
   :members:

Undirliggjandi SSL Client
=========================

.. automodule:: korta.sslclient
   :members:
